========================================================
``psyclone.psyir.transformations.arrayrange2loop_trans``
========================================================

.. automodule:: psyclone.psyir.transformations.arrayrange2loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.arrayrange2loop_trans


Classes
=======

- :py:class:`ArrayRange2LoopTrans`:
  Provides a transformation from a PSyIR Array Range to a PSyIR


.. autoclass:: ArrayRange2LoopTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArrayRange2LoopTrans
      :parts: 1
